@@ -70,7 +70,8 @@ class Trace(object):
 
   def show(cls, message, channel):
     "Show a message out of a channel"
-    message = message.encode('utf-8')
+    if sys.version_info < (3,0):
+      message = message.encode('utf-8')
     channel.write(message + '\n')
 
   debug = classmethod(debug)
@@ -173,7 +174,7 @@ class LineWriter(object):
     "Write a string"
     if not self.file:
       self.file = codecs.open(self.filename, 'w', "utf-8")
-    if self.file == sys.stdout:
+    if self.file == sys.stdout and sys.version_info < (3,0):
       string = string.encode('utf-8')
     self.file.write(string)
 
@@ -222,7 +223,7 @@ class BibStylesConfig(object):
       u'@conference':u'$authors: “$title”, <i>$journal</i>,{ pp. $pages,} $year.{ URL <a href="$url">$url</a>.}{ $note.}', 
       u'@inbook':u'$authors: <i>$title</i>.{{ $publisher,} $year.}{ URL <a href="$url">$url</a>.}{ $note.}', 
       u'@incollection':u'$authors: <i>$title</i>{ in <i>$booktitle</i>{ ($editor, ed.)}}.{{ $publisher,} $year.}{ URL <a href="$url">$url</a>.}{ $note.}', 
-      u'@inproceedings':u'$authors: “$title”, <i>$journal</i>,{ pp. $pages,} $year.{ URL <a href="$url">$url</a>.}{ $note.}', 
+      u'@inproceedings':u'$authors: “$title”, <i>$booktitle</i>,{ pp. $pages,} $year.{ URL <a href="$url">$url</a>.}{ $note.}', 
       u'@manual':u'$authors: <i>$title</i>.{{ $publisher,} $year.}{ URL <a href="$url">$url</a>.}{ $note.}', 
       u'@mastersthesis':u'$authors: <i>$title</i>.{{ $publisher,} $year.}{ URL <a href="$url">$url</a>.}{ $note.}', 
       u'@misc':u'$authors: <i>$title</i>.{{ $publisher,}{ $howpublished,} $year.}{ URL <a href="$url">$url</a>.}{ $note.}', 
@@ -402,7 +403,7 @@ class EscapeConfig(object):
   "Configuration class from elyxer.config file"
 
   chars = {
-      u'\n':u'', u' -- ':u' — ', u'\'':u'’', u'---':u'—', u'`':u'‘', 
+      u'\n':u'', u' -- ':u' — ', u' --- ':u' — ', u'\'':u'’', u'`':u'‘', 
       }
 
   commands = {
@@ -723,7 +724,9 @@ class FormulaConfig(object):
       }
 
   hybridfunctions = {
-      
+      u'\\addcontentsline':[u'{$p!}{$q!}{$r!}',u'f0{}',u'ignored',], 
+      u'\\addtocontents':[u'{$p!}{$q!}',u'f0{}',u'ignored',], 
+      u'\\backmatter':[u'',u'f0{}',u'ignored',], 
       u'\\binom':[u'{$1}{$2}',u'f2{(}f0{f1{$1}f1{$2}}f2{)}',u'span class="binom"',u'span class="binomstack"',u'span class="bigsymbol"',], 
       u'\\boxed':[u'{$1}',u'f0{$1}',u'span class="boxed"',], 
       u'\\cfrac':[u'[$p!]{$1}{$2}',u'f0{f3{(}f1{$1}f3{)/(}f2{$2}f3{)}}',u'span class="fullfraction"',u'span class="numerator align-$p"',u'span class="denominator"',u'span class="ignored"',], 
@@ -732,15 +735,21 @@ class FormulaConfig(object):
       u'\\dbinom':[u'{$1}{$2}',u'(f0{f1{f2{$1}}f1{f2{ }}f1{f2{$2}}})',u'span class="binomial"',u'span class="binomrow"',u'span class="binomcell"',], 
       u'\\dfrac':[u'{$1}{$2}',u'f0{f3{(}f1{$1}f3{)/(}f2{$2}f3{)}}',u'span class="fullfraction"',u'span class="numerator"',u'span class="denominator"',u'span class="ignored"',], 
       u'\\displaystyle':[u'{$1}',u'f0{$1}',u'span class="displaystyle"',], 
+      u'\\fancyfoot':[u'[$p!]{$q!}',u'f0{}',u'ignored',], 
+      u'\\fancyhead':[u'[$p!]{$q!}',u'f0{}',u'ignored',], 
       u'\\fbox':[u'{$1}',u'f0{$1}',u'span class="fbox"',], 
       u'\\fboxrule':[u'{$p!}',u'f0{}',u'ignored',], 
       u'\\fboxsep':[u'{$p!}',u'f0{}',u'ignored',], 
       u'\\fcolorbox':[u'{$p!}{$q!}{$1}',u'f0{$1}',u'span class="boxed" style="border-color: $p; background: $q;"',], 
       u'\\frac':[u'{$1}{$2}',u'f0{f3{(}f1{$1}f3{)/(}f2{$2}f3{)}}',u'span class="fraction"',u'span class="numerator"',u'span class="denominator"',u'span class="ignored"',], 
       u'\\framebox':[u'[$p!][$q!]{$1}',u'f0{$1}',u'span class="framebox align-$q" style="width: $p;"',], 
+      u'\\frontmatter':[u'',u'f0{}',u'ignored',], 
       u'\\href':[u'[$o]{$u!}{$t!}',u'f0{$t}',u'a href="$u"',], 
       u'\\hspace':[u'{$p!}',u'f0{ }',u'span class="hspace" style="width: $p;"',], 
       u'\\leftroot':[u'{$p!}',u'f0{ }',u'span class="leftroot" style="width: $p;px"',], 
+      u'\\mainmatter':[u'',u'f0{}',u'ignored',], 
+      u'\\markboth':[u'{$p!}{$q!}',u'f0{}',u'ignored',], 
+      u'\\markright':[u'{$p!}',u'f0{}',u'ignored',], 
       u'\\nicefrac':[u'{$1}{$2}',u'f0{f1{$1}⁄f2{$2}}',u'span class="fraction"',u'sup class="numerator"',u'sub class="denominator"',u'span class="ignored"',], 
       u'\\parbox':[u'[$p!]{$w!}{$1}',u'f0{1}',u'div class="Boxed" style="width: $w;"',], 
       u'\\raisebox':[u'{$p!}{$1}',u'f0{$1.font}',u'span class="raisebox" style="vertical-align: $p;"',], 
@@ -753,6 +762,7 @@ class FormulaConfig(object):
       u'\\tbinom':[u'{$1}{$2}',u'(f0{f1{f2{$1}}f1{f2{ }}f1{f2{$2}}})',u'span class="binomial"',u'span class="binomrow"',u'span class="binomcell"',], 
       u'\\textcolor':[u'{$p!}{$1}',u'f0{$1}',u'span style="color: $p;"',], 
       u'\\textstyle':[u'{$1}',u'f0{$1}',u'span class="textstyle"',], 
+      u'\\thispagestyle':[u'{$p!}',u'f0{}',u'ignored',], 
       u'\\unit':[u'[$0]{$1}',u'$0f0{$1.font}',u'span class="unit"',], 
       u'\\unitfrac':[u'[$0]{$1}{$2}',u'$0f0{f1{$1.font}⁄f2{$2.font}}',u'span class="fraction"',u'sup class="unit"',u'sub class="unit"',], 
       u'\\uproot':[u'{$p!}',u'f0{ }',u'span class="uproot" style="width: $p;px"',], 
@@ -781,7 +791,7 @@ class FormulaConfig(object):
       u'\\limits':u'LimitPreviousCommand', u'\\newcommand':u'MacroDefinition', 
       u'\\renewcommand':u'MacroDefinition', 
       u'\\setcounter':u'SetCounterFunction', u'\\tag':u'FormulaTag', 
-      u'\\tag*':u'FormulaTag', 
+      u'\\tag*':u'FormulaTag', u'\\today':u'TodayCommand', 
       }
 
   modified = {
@@ -894,7 +904,7 @@ class GeneralConfig(object):
   "Configuration class from elyxer.config file"
 
   version = {
-      u'date':u'2011-08-31', u'lyxformat':u'413', u'number':u'1.2.3', 
+      u'date':u'2013-03-10', u'lyxformat':u'413', u'number':u'1.2.5', 
       }
 
 class HeaderConfig(object):
@@ -923,6 +933,7 @@ class ImageConfig(object):
       
       u'imagemagick':u'convert[ -density $scale][ -define $format:use-cropbox=true] "$input" "$output"', 
       u'inkscape':u'inkscape "$input" --export-png="$output"', 
+      u'lyx':u'lyx -C "$input" "$output"', 
       }
 
   cropboxformats = {
@@ -1081,7 +1092,8 @@ class TranslationConfig(object):
 
   languages = {
       u'american':u'en', u'british':u'en', u'deutsch':u'de', u'dutch':u'nl', 
-      u'english':u'en', u'french':u'fr', u'ngerman':u'de', u'spanish':u'es', 
+      u'english':u'en', u'french':u'fr', u'ngerman':u'de', u'russian':u'ru', 
+      u'spanish':u'es', 
       }
 
 
